-- author: rafftnix
-- date: 24.11.2015

-- ExtraWeights.lua

ExtraWeights = {};

function ExtraWeights.prerequisitesPresent(specializations)
    return true;
end;

function ExtraWeights:load(xmlFile)
	self.setExtraWeights = SpecializationUtil.callSpecializationsFunction("setExtraWeights");
	
	self.extraWeights = {}
	self.currentExtraWeight = 0;
	
	local comp = 1;
	if getXMLInt(xmlFile, "vehicle.extraWeights.compIndex") ~= nil then
		comp = getXMLInt(xmlFile, "vehicle.extraWeights.compIndex")
	end;
	self.extraWeightsDefaultMass = getMass(self.components[comp].node);
	self.extraWeightsDefaultComp = comp;
	
	local num = 0;
	while true do
		local key = "vehicle.extraWeights.weight("..tostring(num)..")";
		if not hasXMLProperty(xmlFile, key) then
			break;
		end;
		local extraWeight = {}
		extraWeight.nodeId = Utils.indexToObject(self.components, getXMLString(xmlFile, key.."#nodeIndex"));
		extraWeight.mass = getXMLFloat(xmlFile, key.."#mass");
		table.insert(self.extraWeights, extraWeight);
		num = num + 1;
	end;
end;

function ExtraWeights:delete()
  
end;

function ExtraWeights:getSaveAttributesAndNodes(nodeIdent)
	local attributes, nodes = "", "";
	attributes = 'extraWeightIndex="'..tostring(self.currentExtraWeight)..'"';
	return attributes, nodes;
end;

function ExtraWeights:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	local extraWeightIndex = Utils.getNoNil(getXMLInt(xmlFile, key.."#extraWeightIndex"), 1);
	self:setExtraWeights(extraWeightIndex, true);
	
	return BaseMission.VEHICLE_LOAD_OK;
end;

function ExtraWeights:writeStream(streamId, connection)
	if not connection:getIsServer() then
		streamWriteInt8(streamId, self.currentExtraWeight);
	end;
end;

function ExtraWeights:readStream(streamId, connection)
	if connection:getIsServer() then
		self:setExtraWeights(streamReadInt8(streamId), true);
	end;
end;

function ExtraWeights:mouseEvent(posX, posY, isDown, isUp, button)
end;

function ExtraWeights:keyEvent(unicode, sym, modifier, isDown)
end;

function ExtraWeights:update(dt)
	if self:getIsActiveForInput() then
		if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA4) then
			self:setExtraWeights(self.currentExtraWeight + 1);
		end;
	end;
end;

function ExtraWeights:draw()
	g_currentMission:addHelpButtonText(g_i18n:getText("extraWeights"), InputBinding.IMPLEMENT_EXTRA4);
end;

function ExtraWeights:setExtraWeights(index, noEventSend)
	if index > table.getn(self.extraWeights) or (self.reckIsAttached ~= nil and self.reckIsAttached) then
		index = 0;
	end;

	local mass = 0;
	for a=1, table.getn(self.extraWeights) do
		local weight = self.extraWeights[a];
		if a <= index then
			mass = mass + weight.mass;
		end;
		setVisibility(weight.nodeId, a<=index);
	end;
	if self.isServer then
		setMass(self.components[self.extraWeightsDefaultComp].node, self.extraWeightsDefaultMass + mass);
	end;
	
	self.currentExtraWeight = index;
	
	if not noEventSend then
		ExtraWeightsEvent.sendEvent(self, index, noEventSend)
	end;
end;